import React, { useMemo } from 'react';
import { SettingsContainer } from '../../components/config';
import { layerTypes } from './components/layers';
import { Input } from '../../..';
import { VisualizationSettingsPropTypes } from '../../common';
import { MapProps } from './mapvis';

export const MapSettings = ({ settings, graphMetadata, updateSettings }: VisualizationSettingsPropTypes<MapProps>) => {
  // const spatialAttributes = useMemo(() => {
  //   if (!settings.node) return [];
  //   return Object.entries(graphMetadata.nodes.types[settings.node].attributes)
  //     .filter((kv) => kv[1].dimension === 'spatial')
  //     .map((kv) => kv[0]);
  // }, [settings.node]);
  const spatialAttributes = useMemo(() => {
    if (!settings.node) return [];
    return Object.entries(graphMetadata.nodes.types[settings.node].attributes).map((kv) => kv[0]);
  }, [settings.node]);

  return (
    <SettingsContainer>
      <Input
        label="Data layer"
        type="dropdown"
        inline
        value={settings.layer}
        options={Object.keys(layerTypes)}
        onChange={(val) => updateSettings({ layer: val as string })}
      />

      <Input
        label="Node Label"
        type="dropdown"
        inline
        value={settings.node}
        options={[...Object.keys(graphMetadata.nodes.types)]}
        disabled={Object.keys(graphMetadata.nodes.types).length < 1}
        onChange={(val) => {
          updateSettings({ node: val as string });
        }}
      />
      <Input
        label="Latitude Location"
        type="dropdown"
        inline
        value={settings.lat}
        options={[...spatialAttributes]}
        disabled={!settings.node || spatialAttributes.length < 1}
        onChange={(val) => updateSettings({ lat: val as string })}
      />

      <Input
        inline
        label="Longitude Location accessor"
        type="dropdown"
        value={settings.lon}
        options={[...spatialAttributes]}
        disabled={!settings.node || spatialAttributes.length < 1}
        onChange={(val) => updateSettings({ lon: val as string })}
      />
    </SettingsContainer>
  );
};
